@@ -12,8 +12,9 @@
 #' @example examples/annotation_raster_interactive.R
 #' @seealso [girafe()]
 #' @export
-annotation_raster_interactive <- function(...)
+annotation_raster_interactive <- function(...) {
   layer_interactive(annotation_raster, ...)
+}
 
 #' @rdname ggiraph-ggproto
 #' @format NULL
@@ -27,7 +28,7 @@ GeomInteractiveRasterAnn <- ggproto(
   draw_panel = function(data, panel_params, coord, ..., .ipar = IPAR_NAMES) {
     zz <- GeomRasterAnn$draw_panel(data, panel_params, coord, ...)
     coords <- coord$transform(data, panel_params)
-    coords <- coords[1,, drop = FALSE]
+    coords <- coords[1, , drop = FALSE]
     add_interactive_attrs(zz, coords, ipar = .ipar)
   }
 )
