@@ -57,7 +57,7 @@ GeomInteractiveErrorbar <- ggproto(
       group = rep(seq_len(nrow(data)), each = 8),
       .size = nrow(data) * 8
     )
-    z <- flip_data(z, flipped_aes)
+    # data <- flip_data(data, flipped_aes)
     z <- copy_interactive_attrs(data, z, each = 8, ipar = .ipar)
     GeomInteractivePath$draw_panel(
       z,
