@@ -402,6 +402,7 @@ opts_selection_theme <- function(
 #' @param min minimum zoom factor
 #' @param max maximum zoom factor
 #' @param duration duration of the zoom transitions, in milliseconds
+#' @param default_on if TRUE, pan/zoom will be activated by default when the plot is rendered
 #' @examples
 #' library(ggplot2)
 #'
@@ -416,11 +417,11 @@ opts_selection_theme <- function(
 #'
 #' x <- girafe(ggobj = gg)
 #' x <- girafe_options(x,
-#'   opts_zoom(min = .7, max = 2) )
+#'   opts_zoom(min = .7, max = 2, default_on = TRUE) )
 #' if( interactive() ) print(x)
 #' @export
 #' @family girafe animation options
-opts_zoom <- function(min = 1, max = 1, duration = 300) {
+opts_zoom <- function(min = 1, max = 1, duration = 300, default_on = FALSE) {
   if (!is_valid_number(min) || min <= 0.2) {
     abort("`min` must be a scalar number, >= 0.2", call = NULL)
   }
@@ -433,11 +434,15 @@ opts_zoom <- function(min = 1, max = 1, duration = 300) {
   if (!is_valid_number(duration) || duration < 0) {
     abort("`duration` must be a scalar positive number", call = NULL)
   }
+  if (!is_valid_logical(default_on)) {
+    abort("`default_on` must be a scalar logical", call = NULL)
+  }
 
   x <- list(
     min = min,
     max = max,
-    duration = duration
+    duration = duration,
+    default_on = default_on
   )
   class(x) <- "opts_zoom"
   x
@@ -469,32 +474,72 @@ opts_zoom <- function(min = 1, max = 1, duration = 300) {
 #' @param fixed if FALSE (default), the toolbar will float above the graphic, if
 #' TRUE, the toolbar will be fixed and always visible.
 #' @param hidden A character vector with the names of the buttons or button groups to be hidden
-#' from the toolbar.
+#' from the toolbar. This allows full customization of which buttons appear.
 #'
-#' Valid button groups: selection, zoom, misc
+#' Valid button groups: 'selection', 'zoom', 'misc'
 #'
-#' Valid button names: lasso_select, lasso_deselect, zoom_onoff, zoom_rect, zoom_reset, saveaspng
+#' Valid button names: 'lasso_select', 'lasso_deselect', 'zoom_onoff', 'zoom_rect', 'zoom_reset', 'saveaspng'
 #'
 #' @note
 #' `saveaspng` relies on JavaScript promises, so any browsers that don't natively
 #' support the standard Promise object will need to have a polyfill (e.g.
 #' Internet Explorer with version less than 11 will need it).
 #' @examples
+#' library(ggiraph)
 #' library(ggplot2)
 #'
 #' dataset <- mtcars
-#' dataset$carname = row.names(mtcars)
+#' dataset$carname <- row.names(mtcars)
 #'
 #' gg <- ggplot(
 #'   data = dataset,
-#'   mapping = aes(x = wt, y = qsec, color = disp,
-#'                 tooltip = carname, data_id = carname) ) +
-#'   geom_point_interactive() + theme_minimal()
+#'   mapping = aes(
+#'     x = wt, y = qsec, color = disp,
+#'     tooltip = carname, data_id = carname
+#'   )
+#' ) +
+#'   geom_point_interactive() +
+#'   theme_minimal()
 #'
-#' x <- girafe(ggobj = gg)
-#' x <- girafe_options(x,
-#'   opts_toolbar(position = "top") )
-#' if( interactive() ) print(x)
+#' x <- girafe(
+#'   ggobj = gg,
+#'   options = list(
+#'     opts_zoom(max = 5),
+#'     opts_selection(only_shiny = FALSE),
+#'     opts_toolbar(position = "top")
+#'   )
+#' )
+#' if (interactive()) print(x)
+#'
+#' # Hide lasso selection tools (useful in Shiny when selections
+#' # are controlled by other app interactions)
+#' x <- girafe(
+#'   ggobj = gg,
+#'   options = list(
+#'     opts_zoom(max = 5),
+#'     opts_selection(only_shiny = FALSE),
+#'     opts_toolbar(
+#'       position = "top",
+#'       hidden = c("lasso_select", "lasso_deselect")
+#'     )
+#'   )
+#' )
+#' if (interactive()) print(x)
+#'
+#'
+#' # Keep only zoom/pan and reset, hide rectangular zoom
+#' x <- girafe(
+#'   ggobj = gg,
+#'   options = list(
+#'     opts_zoom(max = 5),
+#'     opts_selection(only_shiny = FALSE),
+#'     opts_toolbar(
+#'       position = "top",
+#'       hidden = c("selection", "zoom_rect", "saveaspng")
+#'     )
+#'   )
+#' )
+#' if (interactive()) print(x)
 #' @export
 #' @family girafe animation options
 opts_toolbar <- function(
