@@ -20,50 +20,60 @@
 #' @export
 #' @name scale_size_interactive
 #' @family interactive scale
-scale_size_interactive <- function(...)
+scale_size_interactive <- function(...) {
   scale_interactive(scale_size, ...)
+}
 
 #' @export
 #' @rdname scale_size_interactive
-scale_size_area_interactive <- function(...)
+scale_size_area_interactive <- function(...) {
   scale_interactive(scale_size_area, ...)
+}
 
 #' @export
 #' @rdname scale_size_interactive
-scale_size_continuous_interactive <- function(...)
+scale_size_continuous_interactive <- function(...) {
   scale_interactive(scale_size_continuous, ...)
+}
 
 #' @export
 #' @rdname scale_size_interactive
-scale_size_discrete_interactive <- function(...)
+scale_size_discrete_interactive <- function(...) {
   scale_interactive(scale_size_discrete, ...)
+}
 
 #' @export
 #' @rdname scale_size_interactive
-scale_size_binned_interactive <- function(...)
+scale_size_binned_interactive <- function(...) {
   scale_interactive(scale_size_binned, ...)
+}
 
 #' @export
 #' @rdname scale_size_interactive
-scale_size_binned_area_interactive <- function(...)
+scale_size_binned_area_interactive <- function(...) {
   scale_interactive(scale_size_binned_area, ...)
+}
 
 #' @export
 #' @rdname scale_size_interactive
-scale_size_date_interactive <- function(...)
+scale_size_date_interactive <- function(...) {
   scale_interactive(scale_size_date, ...)
+}
 
 #' @export
 #' @rdname scale_size_interactive
-scale_size_datetime_interactive <- function(...)
+scale_size_datetime_interactive <- function(...) {
   scale_interactive(scale_size_datetime, ...)
+}
 
 #' @export
 #' @rdname scale_size_interactive
-scale_size_ordinal_interactive <- function(...)
+scale_size_ordinal_interactive <- function(...) {
   scale_interactive(scale_size_ordinal, ...)
+}
 
 #' @export
 #' @rdname scale_size_interactive
-scale_radius_interactive <- function(...)
+scale_radius_interactive <- function(...) {
   scale_interactive(scale_radius, ...)
+}
